@@ -44,6 +44,8 @@ def printFmtDerivatives():
             print(f'\tTeX deriv.{" " * 3}{derivativeLatex}')
 
 def main():
+    if len(sys.argv == 1):
+        exit('enter a filename')
     printFmtDerivatives()
 
 if __name__ == '__main__':
